:orphan:



.. _sphx_glr_auto_examples:

Examples
========

Below is a gallery of examples



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Warm start to choose regularisation strength">

.. only:: html

 .. figure:: /auto_examples/images/thumb/sphx_glr_example_warm_start_thumb.png

     :ref:`sphx_glr_auto_examples_example_warm_start.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/example_warm_start

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="A sample script for group lasso regression">

.. only:: html

 .. figure:: /auto_examples/images/thumb/sphx_glr_example_logistic_group_lasso_thumb.png

     :ref:`sphx_glr_auto_examples_example_logistic_group_lasso.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/example_logistic_group_lasso

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="A sample script for group lasso regression">

.. only:: html

 .. figure:: /auto_examples/images/thumb/sphx_glr_example_group_lasso_thumb.png

     :ref:`sphx_glr_auto_examples_example_group_lasso.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/example_group_lasso

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="A sample script to demonstrate how the group lasso estimators can be used for variable selectio...">

.. only:: html

 .. figure:: /auto_examples/images/thumb/sphx_glr_example_group_lasso_pipeline_thumb.png

     :ref:`sphx_glr_auto_examples_example_group_lasso_pipeline.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/example_group_lasso_pipeline

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="A sample script for group lasso with dummy variables">

.. only:: html

 .. figure:: /auto_examples/images/thumb/sphx_glr_example_sparse_group_lasso_thumb.png

     :ref:`sphx_glr_auto_examples_example_sparse_group_lasso.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/example_sparse_group_lasso
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_python.zip <//home/yngvem/Programming/morro/group-lasso/docs/auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip <//home/yngvem/Programming/morro/group-lasso/docs/auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
